@@ -321,6 +321,20 @@ pub enum LogLevel {
     Invalid(u8),
 }
 
+impl AsRef<str> for LogLevel {
+    fn as_ref(&self) -> &str {
+        match self {
+            Self::Fatal => "LogLevel FATAL",
+            Self::Error => "LogLevel ERROR",
+            Self::Warn => "LogLevel WARN",
+            Self::Info => "LogLevel INFO",
+            Self::Debug => "LogLevel DEBUG",
+            Self::Verbose => "LogLevel VERBOSE",
+            Self::Invalid(_) => "LogLevel INVALID",
+        }
+    }
+}
+
 /// Represents the kind of a `DLT Trace Message`
 ///
 /// In case the dlt message contains tracing information, the Trace-Type
@@ -340,6 +354,19 @@ pub enum ApplicationTraceType {
     Invalid(u8),
 }
 
+impl AsRef<str> for ApplicationTraceType {
+    fn as_ref(&self) -> &str {
+        match self {
+            Self::Variable => "VARIABLE",
+            Self::FunctionIn => "FUNCTION_IN",
+            Self::FunctionOut => "FUNCTION_OUT",
+            Self::State => "STATE",
+            Self::Vfb => "VFB",
+            Self::Invalid(_) => "INVALID",
+        }
+    }
+}
+
 /// Represents the kind of a `DLT Network Message`
 ///
 /// In case the dlt message contains networking information,
@@ -361,6 +388,21 @@ pub enum NetworkTraceType {
     UserDefined(u8),
 }
 
+impl AsRef<str> for NetworkTraceType {
+    fn as_ref(&self) -> &str {
+        match self {
+            Self::Ipc => "IPC",
+            Self::Can => "CAN",
+            Self::Flexray => "FLEXRAY",
+            Self::Most => "MOST",
+            Self::Ethernet => "ETHERNET",
+            Self::Someip => "SOMEIP",
+            Self::Invalid => "INVALID",
+            Self::UserDefined(_) => "USER_DEFINED",
+        }
+    }
+}
+
 const CTRL_TYPE_REQUEST: u8 = 0x1;
 const CTRL_TYPE_RESPONSE: u8 = 0x2;
 
@@ -376,8 +418,19 @@ pub enum ControlType {
     #[cfg_attr(test, proptest(strategy = "(3..15u8).prop_map(ControlType::Unknown)"))]
     Unknown(u8),
 }
+
+impl AsRef<str> for ControlType {
+    fn as_ref(&self) -> &str {
+        match self {
+            Self::Request => "MSG_TYPE Ctrl(request)",
+            Self::Response => "MSG_TYPE Ctrl(response)",
+            Self::Unknown(_) => "MSG_TYPE Ctrl(unknown)",
+        }
+    }
+}
+
 impl ControlType {
-    pub(crate) fn value(&self) -> u8 {
+    pub fn value(&self) -> u8 {
         match *self {
             ControlType::Request => CTRL_TYPE_REQUEST,
             ControlType::Response => CTRL_TYPE_RESPONSE,
@@ -408,17 +461,16 @@ pub enum MessageType {
     Unknown((u8, u8)),
 }
 
-impl MessageType {
-    pub(crate) fn try_new_from_fibex_message_info(message_info: &str) -> Option<MessageType> {
-        Some(MessageType::Log(match message_info {
-            "DLT_LOG_FATAL" => LogLevel::Fatal,
-            "DLT_LOG_ERROR" => LogLevel::Error,
-            "DLT_LOG_WARN" => LogLevel::Warn,
-            "DLT_LOG_INFO" => LogLevel::Info,
-            "DLT_LOG_DEBUG" => LogLevel::Debug,
-            "DLT_LOG_VERBOSE" => LogLevel::Verbose,
-            _ => return None,
-        }))
+impl AsRef<str> for MessageType {
+    #[inline]
+    fn as_ref(&self) -> &str {
+        match self {
+            Self::Log(level) => level.as_ref(),
+            Self::ApplicationTrace(a) => a.as_ref(),
+            Self::NetworkTrace(n) => n.as_ref(),
+            Self::Control(c) => c.as_ref(),
+            Self::Unknown(_) => "UNKNOWN MSG TYPE",
+        }
     }
 }
 
@@ -507,7 +559,8 @@ pub enum FloatWidth {
     Width32 = 32,
     Width64 = 64,
 }
-pub(crate) fn float_width_to_type_length(width: FloatWidth) -> TypeLength {
+
+pub fn float_width_to_type_length(width: FloatWidth) -> TypeLength {
     match width {
         FloatWidth::Width32 => TypeLength::BitLength32,
         FloatWidth::Width64 => TypeLength::BitLength64,
@@ -834,7 +887,7 @@ impl Argument {
         }
     }
 
-    pub(crate) fn to_real_value(&self) -> Option<u64> {
+    pub fn to_real_value(&self) -> Option<u64> {
         match (&self.type_info.kind, &self.fixed_point) {
             (TypeInfoKind::SignedFixedPoint(_), Some(_)) => self.log_v(),
             (TypeInfoKind::UnsignedFixedPoint(_), Some(_)) => self.log_v(),
